<template>
  <div class="rightContent">
    <div class="top">
      <SearchCommonView
        :add-title="'新建'"
        :placeholder="'请输入业务类型'"
        :amount-view="false"
        @addCommonClick="addBtnClick"
        @searchClick="getList"
      />
    </div>
    <div class="list-view">
      <div class="table">
        <TableCommonView ref="tableListRef" :table-list="tableList" :show-checkcol="false">
          <template slot="tableButton">
            <el-table-column label="操作" width="100">
              <template slot-scope="scope">
                <el-button @click="tableRowClick(scope.row, '查看')" type="text" size="small">查看</el-button>
                <el-button @click="tableRowClick(scope.row, '编辑')" type="text" size="small">编辑</el-button>
              </template>
            </el-table-column>
          </template>
        </TableCommonView>
      </div>
      <div class="btn-pager">
        <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
      </div>
    </div>
    <!-- 新建/编辑 -->
    <AddBussinessType v-if="editConfig.visible" @refresh="refresh" :edit-common-config="editConfig" />
  </div>
</template>

<script>
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import { getOperationTypeList } from "@/api/warehouseManage/warehouse"
// import DetailProduct from "@/views/productManage/product/DetailProduct"
import AddBussinessType from "@/views/warehouseManage/bussinessType/AddBussinessType"

export default {
  name: "WarehouseView",
  props: {},
  components: { AddBussinessType },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      tableList: {},
      keyword: "",
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      }
    }
  },
  created() {
    this.setTable()
    this.getData()
  },
  methods: {
    setTable() {
      this.tableList = {
        tableInfomation: [],
        selectBox: false,
        selectIndex: true,
        showcol: this.showcol,
        allcol: [],
        tableColumn: this.setTableColumn(this.showcol)
      }
      let allcol = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        if (!this.tableList.tableColumn[i].default) {
          const label = this.tableList.tableColumn[i].label
          allcol.push(label)
        }
      }
      this.tableList.allcol = allcol
    },
    setTableColumn(showcol) {
      console.log(showcol)
      let tableColumn = [
        {
          label: "业务类型",
          prop: "name",
          isShowColumn: true,
          default: true
        },
        {
          label: "仓库",
          propType: "mulitple",
          propTwo: "name",
          prop: "warehouse",
          isShowColumn: true,
          default: true
        }
      ]
      return tableColumn
    },
    selTableCol(val) {
      this.showcol = val
      this.tableList.tableColumn = this.setTableColumn(val)
    },
    // 请求数据
    async getData() {
      await getOperationTypeList({
        keyword: this.keyword,
        page: this.pagerOptions.currPage,
        pageSize: this.pagerOptions.pageSize
      }).then((res) => {
        if (res.code === 200) {
          const list = res.data
          this.tableList.tableInfomation = list || []
          this.pagerOptions.totalCount = res.total
        }
      })
    },
    refresh() {
      this.pagerOptions.currPage = 1
      this.getData()
    },
    // 搜索
    getList(val) {
      this.keyword = val
      this.pagerOptions.currPage = 1
      this.getData()
    },
    // 行点击
    tableRowClick(row, val) {
      this.editConfig.title = val
      let obj = JSON.parse(JSON.stringify(row))
      for (let i in obj) {
        if (i == "name" || i == "prefix") {
          obj[i] = obj[i] ? obj[i] : ""
        } else {
          obj[i] = obj[i] ? obj[i] : null
        }
      }
      this.editConfig.infomation = { ...obj }
      this.editConfig.visible = true
    },
    // 新建
    addBtnClick() {
      this.editConfig.title = "新建"
      this.editConfig.infomation = {
        name: "",
        prefix: "",
        // 作业类型
        baseOperationType: null,
        // 退货类型
        returnOperationTypeID: null,
        // 创建欠单
        createBackorder: null,
        // 仓库
        warehouseId: null,
        // 显示作业详情
        showOperations: false,
        earlyOperations: null,
        // 保留方式
        reservationMethod: 1,
        // 默认原位置
        defaultLocationSrcId: null,
        // 默认目标位置
        defaultLocationDestId: null
      }
      this.editConfig.visible = true
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped></style>
